@@ -349,9 +349,9 @@ effect:
 
     def save_image_from_noise(self, noise, name='image.pdf'):
 
-
         img = self.get_image(noise)
-        self.plot_image(img, name=name)
+        self.plot_image(img[:,::-1], name=name)
+
 
     def get_random_image(self):
 
@@ -646,16 +646,16 @@ effect:
                 hist= self.gan.train_on_batch(noisevector, y_gen)
 
                 if self.diagnostics:
-                    discloss.append( hist[2] )
-                    chi2.append( hist[1] )
+                    discloss.append( hist[1] )
+                    chi2.append( hist[2] )
 
             img = self.get_image(noisevector)
             img = (img+1)/2
             if self.diagnostics:
                 self.give_imgrec_diagnostics(hist, chi2, discloss, r, epochs, mu)
-                self.save_image_from_noise(noisevector, name=f'{self.dir}/Image_restart{r}.pdf')
-            Chi2s.append(hist[1])
-            DisLoss.append(hist[2])
+                self.save_image_from_noise(noisevector, name=os.path.join(self.dir,f'Image_restart{r}.pdf') )
+            Chi2s.append(hist[2])
+            DisLoss.append(hist[1])
             Images.append(img[:,::-1])
             Vectors.append(noisevector)
 
@@ -688,7 +688,7 @@ effect:
         # plot image
         self.plot_image(best, name=os.path.join(os.getcwd(),self.dir,'BestImage.pdf'), chi2=f'chi2={fdatabest:.1f}')
         # save image
-        self.imagetofits(median, ftot[id], fdatabest, frglbest, name=os.path.join(os.getcwd(),self.dir,'BestImage.fits'))
+        self.imagetofits(median[0,:,:,0], ftot[id], fdatabest, frglbest, name=os.path.join(os.getcwd(),self.dir,'BestImage.fits'))
 
 
     def imagetofits(self, image, ftot, fdata, frgl, name='Image.fits'):
@@ -1144,6 +1144,7 @@ effect:
                 plotObservablesComparison(V2image, V2, V2e, CPimage, CP, CPe)
                 return lossValue, V2loss , CPloss
 
+        self.data_loss = data_loss
         return data_loss
 
 
@@ -1363,6 +1364,6 @@ class inputImages:
 
 if "__main__" == __name__:
     test = GAN()
-    dir = 'caca/'
-    file = 'pipi'
+    dir = './'
+    file = 'Test'
     imgs = inputImages(dir, file)
